@@ -22,9 +22,11 @@ class FileLoadContextManager:
 
 class FileRepository:
     _sections: Type[Enum]
+    debug: bool
 
-    def __init__(self, sections: Type[Enum] = AppFileSections):
+    def __init__(self, sections: Type[Enum] = AppFileSections, debug: bool = False):
         self._sections = sections
+        self.debug = debug
 
     async def stash(self, filename: str, section: Enum, data: Any, raises: bool = True, **kwargs):
         raise NotImplementedError
