@@ -97,10 +97,11 @@ class HttpServer(Worker):
         sock.set_inheritable(True)
         return sock
 
-    async def broadcasts_rt(self, message: GenericIMessage):
+    async def broadcasts_rt(self, message: GenericIMessage, resolve_callback: RtEventCallback = None):
         promises = []
         for conn in self.rt_connections:
-            promises.append(conn.send_after_call(message))
+            if conn.resolve_callback.__name__ == resolve_callback.__name__:
+                promises.append(conn.send_after_call(message))
         await asyncio.gather(*promises)
 
     async def accept_rt_connection(self, conn: RtConnection,
@@ -151,6 +152,8 @@ def create_io_workers(server_cls: Type[HttpServer],
 
 def create_rt_subscribes(*workers: HttpServer,
                          event_type: List[Type[IMessage] | str] | Type[IMessage] | str,
-                         **kwargs, ):
+                         resolve_callback: RtEventCallback,
+                         **kwargs):
     for worker in workers:
-        worker.channel.add_event_listener(event_type, worker.broadcasts_rt, **kwargs)
+        worker.channel.add_event_listener(event_type, partial(worker.broadcasts_rt, resolve_callback=resolve_callback),
+                                          **kwargs)
\ No newline at end of file
